/**
 * @author guoqichao
 */

angular.module('starter.search', ['ionic',
    'ngCordova',
    'ngResource',
    'starter.services'
  ])
  .controller('SearchCtrl', function ($scope,
    $rootScope,
    $ionicPopup,
    $location,
    $stateParams,
    $sce,
    $ionicLoading,
    Toolkit,
    getAnnuProductCodesService,
    SearchSuggestService,
    SearchFindCodeService,
    FullSearch) {
    $scope.queryCondition = {
      fullKeyWordInput: '',
      fullSearchTypeInput: 'name',
      fullTimeOrderInput: 'disclosureDate',
      fullTimeRangeInput: '06',
      pageNo: 1
    }

    // 搜索内容类型
    $scope.ContentType = {
      ANNOUNCEMENT: 1, // 公告
      PRODUCT: 2 // 产品
    };
    // 当前搜索内容，默认为公告
    $scope.currentContentType = 1;

    $scope.queryCondition.fullKeyWordInput = $stateParams.searchName;
    $scope.products = null;
    $scope.annus = null;
    $scope.hasMoreData = false;

    $scope.trustHtml = function (data) {
      return $sce.trustAsHtml('<div>' + data + '</div>');
    }

    $scope.changeContentType = function (type) {
      $scope.currentContentType = type;
      $scope.queryCondition.pageNo = 1;
      $scope.products = null;
      $scope.annus = null;
      $scope.hasMoreData = false;
      $scope.fullSearch($scope.queryCondition.fullKeyWordInput, false);
    }

    $scope.loadMore = function () {
      // 上拉刷新
      if ($scope.queryCondition.fullKeyWordInput) {
        $scope.fullSearch($scope.queryCondition.fullKeyWordInput, true);
      }
      //   $scope.$broadcast('scroll.infiniteScrollComplete');
    }
    $scope.loadProductCodes = function () {
      if (Global.ProductCodes) {
        $scope.codeList = Global.ProductCodes.stocks.concat(Global.ProductCodes.funds, Global.ProductCodes.bonds);
        return;
      }
      Global.ProductCodes = JSON.parse(window.localStorage.getItem("product-codes"));
      if (Global.ProductCodes && Global.ProductCodes.stocks) {
        $scope.codeList = Global.ProductCodes.stocks.concat(Global.ProductCodes.funds, Global.ProductCodes.bonds);
      }
      var promise = getAnnuProductCodesService.query().$promise;

      promise.then(function (_response) {
        if (_response.status == "1") {
          Global.ProductCodes = _response.codes;
          window.localStorage.setItem("product-codes", JSON.stringify(Global.ProductCodes));
          $scope.codeList = Global.ProductCodes.stocks.concat(Global.ProductCodes.funds, Global.ProductCodes.bonds);

        } else {}
      }, function () {});
    }();

    $scope.onChange = function (keyword) {
      if (keyword.getByteSize() > 2 && keyword.length > 1) {
        $scope.showCodeList = true;
        SearchSuggestService.query({
          keyword: keyword
        }).$promise.then(function (_response) {
          if (_response.status == 0) {
            $scope.filterCodeList = [];
            _response.data.forEach(function (v) {
              v.toString = function () {
                return (v.code ? v.code : "") + ' ' + (v.typeLabel ? v.typeLabel : "") + ' ' + (v.name ? v.name : "");
              }
              $scope.filterCodeList.push(v);
            });
          }
        });
      } else {
        $scope.showCodeList = false;
      }
    };
    $scope.fullSearch = function (keyword, isAppend) {
      window.localStorage.setItem("tab.home.searchName", keyword)
      $scope.showCodeList = false;
      var re = new RegExp("[`~!@#$^&*()=|{}':;',\\[\\].<>/?~！@#￥……&*（）;—|{}【】‘；：”“'。，、？《》]");
      if (keyword == "") {
        Toolkit.alert("请输入需要搜索的内容");
        return;
      }
      if (re.test(keyword)) {
        Toolkit.alert("关键字不能包含特殊字符");
        return;
      }
      if (keyword.length > 50) {
        Toolkit.alert("关键字不能超过20个字符");
        return;
      }
      var x = re.test(keyword);

      if (!isAppend) {
        $scope.queryCondition.pageNo = 1;
        $ionicLoading.show();
      }

      $scope.queryCondition.fullKeyWordInput = keyword;
      var stocklist = null;
      var promise = FullSearch.query($scope.queryCondition).$promise;

      promise.then(function (_response) {
        if (_response.product.responseCode == 1000 &&
          $scope.currentContentType == $scope.ContentType.PRODUCT) {
          _response.product.resultData = $scope.formatProduct(_response.product.resultData);
          if (isAppend) {
            $scope.products.resultData = $scope.products.resultData.concat(_response.product.resultData);
          } else {
            $scope.products = _response.product;
          }
          $scope.hasMoreData = _response.product.resultData.length > 9;
          $scope.queryCondition.pageNo += 1;
        }
        if (_response.annu.responseCode == 1000 &&
          $scope.currentContentType == $scope.ContentType.ANNOUNCEMENT) {
          if (isAppend) {
            $scope.annus.resultData = $scope.annus.resultData.concat(_response.annu.resultData);
          } else {
            $scope.annus = _response.annu;
          }
          //数据刷新成功后，如果数据不够10条，关闭上拉加载，防止反复触发加载
          $scope.hasMoreData = _response.annu.resultData.length > 9;
          $scope.queryCondition.pageNo += 1;
        }
        if (!isAppend) {
          $ionicLoading.hide();
        }
        $scope.$broadcast('scroll.infiniteScrollComplete');
      }, function () {

        $scope.hasMoreData = false;
        if (!isAppend) {
          $ionicLoading.hide();
        }

        $scope.$broadcast('scroll.infiniteScrollComplete');
        Toolkit.alert('网络信号不好 (:');
      });
    }

    $scope.goProductDetail = function (product) {
      var categoryMId = product.mediumCategoryId;
      var mainCategoryId = product.mainCategoryId;

      if (categoryMId == '201612') {
        $location.path('/tab/stockProList/getProdPrivatefundList/9590/09/私募基金/0/201612/2016/' + product.name.replace(/<(?:.|\s)*?>/g, ""));
        return
      } else if (categoryMId == '201213') {
        $location.path('/tab/stockProList/getProdFundList/9586/19/公募基金/21/201213/2012/' + product.name.replace(/<(?:.|\s)*?>/g, ""));
        return
      } else if (categoryMId == '201212') {
        $location.path('/tab/stockProList/getProdFundList/9586/19/公募基金/21/201212/2012/' + product.name.replace(/<(?:.|\s)*?>/g, ""));
        return
      }

      var promise = SearchFindCodeService.query({
        prodId: product.url,
        categoryId: product.mediumCategoryId
      }).$promise;

      promise.then(function (_response) {
        if (_response.status != 0) {
          return;
        }
        var code = _response.data.code || _response.data.prod_id || product.url;
        switch (mainCategoryId) {
          case '2010':
            {
              $location.path('/stockDetail/' + code + "/getAnnuStockList/getProdStockDetail/");
              break;
            }
          case '2011':
            {
              $location.path('/stockDetail/' + code + "/getAnnuSharetransferList/getProdSharetransferDetail/");
              break;
            }
          case '2012':
            {
              $location.path('/stockDetail/' + code + "/getAnnuFundList/getProdFundDetail/" + categoryMId);
              //$location.path('/stockDetail/'+$scope.detailCode+"/getAnnuFundList/getProdFundDetail/");
              break;
            }
          case '2013':
            {
              $location.path('/stockDetail/' + code + "/getAnnuFundMutualList/getProdFundMutualDetail/");
              break;
            }
          case '2014':
            {
              $location.path('/stockDetail/' + code + "/getAnnuBondList/getProdBondDetail/" + categoryMId);
              break;
            }
          case '2015':
            {
              $location.path('/stockDetail/' + code + "/getAnnuAbsList/getProdAbsDetail/" + categoryMId);
              break;
            }
          case '2016':
            {
              $location.path('/stockDetail/' + code + "//getProdPrivatefundDetail/" + categoryMId);
              break;
            }
            // case 'warran':
            //   {
            //     $location.path('/stockDetail/' + $scope.detailCode + "/getAnnuWarrantList/getProdWarrantDetail/");
            //     break;
            //   }
          case '2018':
            {
              $location.path('/stockDetail/' + code + "//getRegularFirmDetail/" + categoryMId);
            }
          default:
            {}
        }
      });
    }

    $scope.formatProduct = function (productList) {
      productList.forEach(function (v) {
        var mainCategory = Toolkit.getCategoryByKey(v.mainCategoryId);
        var mediumCategory = Toolkit.getCategoryByKey(v.mediumCategoryId);
        v.mainCategoryName = mainCategory ? mainCategory.value : '';
        v.mediumCategoryName = mediumCategory ? mediumCategory.value : '';
      })
      console.log(productList);
      return productList;
    }

    // $scope.getDocDetail = function (type, url) {
    //   var fullUrl = Global.WEB + url;
    //   Toolkit.openFile(fullUrl);
    // }

    $scope.goDetail = function (annu) {
      console.log(annu)
      if (annu.mainCategoryId.toString().startsWith("10")) {
        var type = annu.docType
        var url = annu.url
        var name =  annu.name.replace(/<(?:.|\s)*?>/g, "");
        var date = annu.disclosureDate
        if (type == "txt"
          && !url.endsWith(".pdf")
          && !url.endsWith(".doc")
          && !url.endsWith(".docx")
          && !url.endsWith(".xls")
          && !url.endsWith(".xlsx")) {
          var fullUrl = Global.HOST + "/Disclosure/openHtml.do?name=" + name + "&date=" + date + "&path=" + url;
          window.open(fullUrl, '_system');
        } else if (type == "xbrl") {
          var fullUrl = Global.XBRLHOST + url;
          window.open(fullUrl, '_system');
        } else {
          var fullUrl = url;
          if (url.indexOf("http://") < 0) {
            var fullUrl = Global.WEB + url;
          }
          Toolkit.openFile(fullUrl);
        }
      } else if (annu.mainCategoryId.toString().startsWith("40")) {
        if (annu.mainCategoryId =="4010") {
          $location.path('/regularDetail/' + annu.url + "/getRegularAdminDetail/" + annu.mediumCategoryId);
        } else if (annu.mainCategoryId == "4011") {
          $location.path('/regularDetail/' + annu.url + "/getRegularDiskDetail/" + annu.mediumCategoryId);
        }
      }
    }

    $scope.$on("$ionicView.enter", function (event, data) {
      if (data.stateParams.searchName) {
        $scope.searchName = window.localStorage.getItem('tab.home.searchName')
        $scope.fullSearch($scope.searchName, false);
      }
    });
    $scope.setQueryCode = function (item) {
      var detailCode = item.code ? item.code : item.prodId;
      $scope.showCodeList = false;

      if (item.channelPath.indexOf("2010") == 0) {
        $location.path('/stockDetail/' + detailCode + "/getAnnuStockList/getProdStockDetail/");
      } else if (item.channelPath.indexOf("2011") == 0) {
        $location.path('/stockDetail/' + detailCode + "/getAnnuSharetransferList/getProdSharetransferDetail/");
      } else if (item.channelPath.indexOf("2012") == 0) {
        if (item.channelPath != "201212" && item.channelPath != "201213") {
          $location.path('/stockDetail/' + detailCode + "/getAnnuFundList/getProdFundDetail/" + item.channelPath);
        }
      } else if (item.channelPath.indexOf("2013") == 0) {
        $location.path('/stockDetail/' + detailCode + "/getAnnuFundMutualList/getProdFundMutualDetail/");
      } else if (item.channelPath.indexOf("2014") == 0) {
        $location.path('/stockDetail/' + detailCode + "/getAnnuBondList/getProdBondDetail/" + item.channelPath);
      } else if (item.channelPath.indexOf("2015") == 0) {
        $location.path('/stockDetail/' + detailCode + "/getAnnuAbsList/getProdAbsDetail/");
      } else if (item.channelPath.indexOf("2016") == 0) {
        if (item.channelPath != '201612') {
          $location.path('/stockDetail/' + detailCode + "//getProdPrivatefundDetail/" + item.channelPath);
        }
      } else if (item.channelPath.indexOf("2018") == 0) {
        $location.path('/stockDetail/' + detailCode + "//getRegularFirmDetail/" + item.channelPath);
      }

      $scope.queryCondition.fullKeyWordInput = item.code ? item.code : item.name;
    }
  })
